pub struct BroadcastId {
pub origin: NodeId,
pub seq: u64,
}Expand description
Names one broadcast uniquely: who originated it, and their sequence number for it.
Fields
origin: NodeIdseq: u64Trait Implementations
Sourceimpl Clone for BroadcastId
impl Clone for BroadcastId
Sourcefn clone(&self) -> BroadcastId
fn clone(&self) -> BroadcastId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for BroadcastId
Sourceimpl Debug for BroadcastId
impl Debug for BroadcastId
Sourceimpl<'de> Deserialize<'de> for BroadcastId
impl<'de> Deserialize<'de> for BroadcastId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BroadcastId
Sourceimpl Hash for BroadcastId
impl Hash for BroadcastId
Sourceimpl Ord for BroadcastId
impl Ord for BroadcastId
Sourcefn cmp(&self, other: &BroadcastId) -> Ordering
fn cmp(&self, other: &BroadcastId) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BroadcastId
impl PartialEq for BroadcastId
Sourcefn eq(&self, other: &BroadcastId) -> bool
fn eq(&self, other: &BroadcastId) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BroadcastId
impl PartialOrd for BroadcastId
Sourceimpl Serialize for BroadcastId
impl Serialize for BroadcastId
impl StructuralPartialEq for BroadcastId